==> attal_0.8.orig.tar.gz: attal-0.8/i18n/fr/attal_client_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ClientInterface</name>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation>CTRL+M</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Connection impossible</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Vous êtes déjà connecté(e). Déconnectez-vous d&apos;abord.</translation>
    </message>
    <message>
        <source>Attal - Lords of Doom</source>
        <translation>Attal - Lords of Doom</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Connection au serveur</translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation>&amp;Connexion au serveur</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Déconnexion</translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation>Mini-carte</translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation>&amp;Mini-carte</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jeu</translation>
    </message>
    <message>
        <source>Match</source>
        <translation>Partie</translation>
    </message>
    <message>
        <source>Do you want abandon the match ?</source>
        <translation>Voulez-vous abandonner la partie ?</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barre de statut</translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Tab Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation>Connexion au serveur</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Hôte :</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Port :</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connecter</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
</TS>

==> attal_0.9.1.orig.tar.gz: attal-0.9.1/i18n/fr/attal_client_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ClientInterface</name>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation>CTRL+M</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Connection impossible</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Vous êtes déjà connecté(e). Déconnectez-vous d&apos;abord.</translation>
    </message>
    <message>
        <source>Attal - Lords of Doom</source>
        <translation>Attal - Lords of Doom</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Connection au serveur</translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation>&amp;Connexion au serveur</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Déconnexion</translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation>Mini-carte</translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation>&amp;Mini-carte</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jeu</translation>
    </message>
    <message>
        <source>Match</source>
        <translation>Partie</translation>
    </message>
    <message>
        <source>Do you want abandon the match ?</source>
        <translation>Voulez-vous abandonner la partie ?</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barre de statut</translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation>Onglets</translation>
    </message>
    <message>
        <source>&amp;Tab Window</source>
        <translation>&amp;Onglets</translation>
    </message>
    <message>
        <source>CTRL+T</source>
        <translation>CTRL+T</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation>CTRL+P</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Impossible de charger le thème</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Thème</translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation>n&apos;a pas été chargé correctement</translation>
    </message>
    <message>
        <source>Fast Server </source>
        <translation>Serveur</translation>
    </message>
    <message>
        <source>Fast &amp;Server</source>
        <translation>&amp;Serveur</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation>Connexion au serveur</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Hôte :</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Port :</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connecter</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
</TS>
